==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/fishing/gearshooting/GearShootingTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.fishing.gearshooting;

/*
 * #%L
 * Tutti :: UI
 * $Id: GearShootingTableModel.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/fishing/gearshooting/GearShootingTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;

import javax.swing.table.TableColumnModel;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author kmorin
 * @since 0.3
 */
public class GearShootingTableModel extends AbstractTuttiTableModel<GearShootingRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<GearShootingRowModel> KEY = ColumnIdentifier.newId(
            GearShootingRowModel.PROPERTY_KEY,
            n_("tutti.table.fishing.gearShooting.header.key"),
            n_("tutti.table.fishing.gearShooting.header.key"));

    public static final ColumnIdentifier<GearShootingRowModel> VALUE = ColumnIdentifier.newId(
            GearShootingRowModel.PROPERTY_VALUE,
            n_("tutti.table.fishing.gearShooting.header.value"),
            n_("tutti.table.fishing.gearShooting.header.value"));

    public GearShootingTableModel(TableColumnModel columnModel) {
        super(columnModel, false, false);
        setNoneEditableCols(KEY);
    }

    @Override
    public GearShootingRowModel createNewRow() {
        GearShootingRowModel result = new GearShootingRowModel();
        return result;
    }

}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/fishing/gearshooting/GearShootingTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.fishing.gearshooting;

/*
 * #%L
 * Tutti :: UI
 * $Id: GearShootingTableModel.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/fishing/gearshooting/GearShootingTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;

import javax.swing.table.TableColumnModel;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author kmorin
 * @since 0.3
 */
public class GearShootingTableModel extends AbstractTuttiTableModel<GearShootingRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<GearShootingRowModel> KEY = ColumnIdentifier.newId(
            GearShootingRowModel.PROPERTY_KEY,
            n_("tutti.table.fishing.gearShooting.header.key"),
            n_("tutti.table.fishing.gearShooting.header.key"));

    public static final ColumnIdentifier<GearShootingRowModel> VALUE = ColumnIdentifier.newId(
            GearShootingRowModel.PROPERTY_VALUE,
            n_("tutti.table.fishing.gearShooting.header.value"),
            n_("tutti.table.fishing.gearShooting.header.value"));

    public GearShootingTableModel(TableColumnModel columnModel) {
        super(columnModel, false, false);
        setNoneEditableCols(KEY);
    }

    @Override
    public GearShootingRowModel createNewRow() {
        GearShootingRowModel result = new GearShootingRowModel();
        return result;
    }

}
